==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/papirus-antix.pm <==
<?xml version="1.0"?>
<app>

<category>
Icons
</category>

<name>
Papirus antiX
</name>

<description>
   <am>Full version of Papirus icons for antiX Linux</am>
   <ar>Full version of Papirus icons for antiX Linux</ar>
   <be>Full version of Papirus icons for antiX Linux</be>
   <bg>Full version of Papirus icons for antiX Linux</bg>
   <bn>Full version of Papirus icons for antiX Linux</bn>
   <ca>Full version of Papirus icons for antiX Linux</ca>
   <cs>Full version of Papirus icons for antiX Linux</cs>
   <da>Full version of Papirus icons for antiX Linux</da>
   <de>Piktogramme (Ugs.: “Icons”) für antiX im Stil “Numix Bevil” (Vollständiger Satz)</de>
   <el>Πλήρης έκδοση εικονιδίων Papirus για antiX Linux</el>
   <en>Full version of Papirus icons for antiX Linux</en>
   <es_ES>Full version of Papirus icons for antiX Linux</es_ES>
   <es>Versión completa de los iconos Papirus para antiX Linux</es>
   <et>Full version of Papirus icons for antiX Linux</et>
   <eu>Full version of Papirus icons for antiX Linux</eu>
   <fa>Full version of Papirus icons for antiX Linux</fa>
   <fil_PH>Full version of Papirus icons for antiX Linux</fil_PH>
   <fi>Full version of Papirus icons for antiX Linux</fi>
   <fr_BE>Full version of Papirus icons for antiX Linux</fr_BE>
   <fr>Icônes pour antiX dans le style “Papirus” (version complète)</fr>
   <gl_ES>Full version of Papirus icons for antiX Linux</gl_ES>
   <he_IL>Full version of Papirus icons for antiX Linux</he_IL>
   <hi>Full version of Papirus icons for antiX Linux</hi>
   <hr>Full version of Papirus icons for antiX Linux</hr>
   <hu>Full version of Papirus icons for antiX Linux</hu>
   <id>Full version of Papirus icons for antiX Linux</id>
   <is>Full version of Papirus icons for antiX Linux</is>
   <it>Full version of Papirus icons for antiX Linux</it>
   <ja>AntiX Linux用 Papirusアイコンのフルバージョン</ja>
   <kk>Full version of Papirus icons for antiX Linux</kk>
   <ko>Full version of Papirus icons for antiX Linux</ko>
   <lt>Full version of Papirus icons for antiX Linux</lt>
   <mk>Full version of Papirus icons for antiX Linux</mk>
   <mr>Full version of Papirus icons for antiX Linux</mr>
   <nb_NO>Full version of Papirus icons for antiX Linux</nb_NO>
   <nb>Full versjon av Papirus-ikoner for antiX Linux</nb>
   <nl_BE>Full version of Papirus icons for antiX Linux</nl_BE>
   <nl>Full version of Papirus icons for antiX Linux</nl>
   <pl>Full version of Papirus icons for antiX Linux</pl>
   <pt_BR>Conjunto completo de ícones Papirus para o antiX Linux</pt_BR>
   <pt>Full version of Papirus icons for antiX Linux</pt>
   <ro>Full version of Papirus icons for antiX Linux</ro>
   <ru>Full version of Papirus icons for antiX Linux</ru>
   <sk>Full version of Papirus icons for antiX Linux</sk>
   <sl>Full version of Papirus icons for antiX Linux</sl>
   <sq>Full version of Papirus icons for antiX Linux</sq>
   <sr>Full version of Papirus icons for antiX Linux</sr>
   <sv>Full version av Papirus ikoner för antiX Linux</sv>
   <th>Full version of Papirus icons for antiX Linux</th>
   <tr>Full version of Papirus icons for antiX Linux</tr>
   <uk>Full version of Papirus icons for antiX Linux</uk>
   <vi>Full version of Papirus icons for antiX Linux</vi>
   <zh_CN>Full version of Papirus icons for antiX Linux</zh_CN>
   <zh_HK>Full version of Papirus icons for antiX Linux</zh_HK>
   <zh_TW>Full version of Papirus icons for antiX Linux</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
papiris-antix
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
papiris-antix
</uninstall_package_names>
</app>

==> packageinstaller-pkglist_0.3.30.tar.xz: packageinstaller-pkglist/papirus-antix.pm <==
<?xml version="1.0"?>
<app>

<category>
Icons
</category>

<name>
Papirus antiX
</name>

<description>
   <am>Full version of Papirus icons for antiX Linux</am>
   <ar>Full version of Papirus icons for antiX Linux</ar>
   <be>Full version of Papirus icons for antiX Linux</be>
   <bg>Full version of Papirus icons for antiX Linux</bg>
   <bn>Full version of Papirus icons for antiX Linux</bn>
   <ca>Full version of Papirus icons for antiX Linux</ca>
   <cs>Full version of Papirus icons for antiX Linux</cs>
   <da>Full version of Papirus icons for antiX Linux</da>
   <de>Piktogramme (Ugs.: “Icons”) für antiX im Stil “Numix Bevil” (Vollständiger Satz)</de>
   <el>Πλήρης έκδοση εικονιδίων Papirus για antiX Linux</el>
   <en>Full version of Papirus icons for antiX Linux</en>
   <es_ES>Full version of Papirus icons for antiX Linux</es_ES>
   <es>Versión completa de los iconos Papirus para antiX Linux</es>
   <et>Full version of Papirus icons for antiX Linux</et>
   <eu>Full version of Papirus icons for antiX Linux</eu>
   <fa>Full version of Papirus icons for antiX Linux</fa>
   <fil_PH>Full version of Papirus icons for antiX Linux</fil_PH>
   <fi>Full version of Papirus icons for antiX Linux</fi>
   <fr_BE>Icônes pour antiX dans le style “Papirus” (version complète)</fr_BE>
   <fr>Icônes pour antiX dans le style “Papirus” (version complète)</fr>
   <gl_ES>Full version of Papirus icons for antiX Linux</gl_ES>
   <he_IL>Full version of Papirus icons for antiX Linux</he_IL>
   <hi>Full version of Papirus icons for antiX Linux</hi>
   <hr>Full version of Papirus icons for antiX Linux</hr>
   <hu>Full version of Papirus icons for antiX Linux</hu>
   <id>Full version of Papirus icons for antiX Linux</id>
   <is>Full version of Papirus icons for antiX Linux</is>
   <it>Full version of Papirus icons for antiX Linux</it>
   <ja>AntiX Linux用 Papirusアイコンのフルバージョン</ja>
   <kk>Full version of Papirus icons for antiX Linux</kk>
   <ko>Full version of Papirus icons for antiX Linux</ko>
   <lt>Full version of Papirus icons for antiX Linux</lt>
   <mk>Full version of Papirus icons for antiX Linux</mk>
   <mr>Full version of Papirus icons for antiX Linux</mr>
   <nb_NO>Full version of Papirus icons for antiX Linux</nb_NO>
   <nb>Full versjon av Papirus-ikoner for antiX Linux</nb>
   <nl_BE>Full version of Papirus icons for antiX Linux</nl_BE>
   <nl>Full version of Papirus icons for antiX Linux</nl>
   <pl>Full version of Papirus icons for antiX Linux</pl>
   <pt_BR>Conjunto completo de ícones Papirus para o antiX Linux</pt_BR>
   <pt>Full version of Papirus icons for antiX Linux</pt>
   <ro>Full version of Papirus icons for antiX Linux</ro>
   <ru>Full version of Papirus icons for antiX Linux</ru>
   <sk>Full version of Papirus icons for antiX Linux</sk>
   <sl>Full version of Papirus icons for antiX Linux</sl>
   <sq>Full version of Papirus icons for antiX Linux</sq>
   <sr>Full version of Papirus icons for antiX Linux</sr>
   <sv>Full version av Papirus ikoner för antiX Linux</sv>
   <th>Full version of Papirus icons for antiX Linux</th>
   <tr>Full version of Papirus icons for antiX Linux</tr>
   <uk>Full version of Papirus icons for antiX Linux</uk>
   <vi>Full version of Papirus icons for antiX Linux</vi>
   <zh_CN>Full version of Papirus icons for antiX Linux</zh_CN>
   <zh_HK>Full version of Papirus icons for antiX Linux</zh_HK>
   <zh_TW>Full version of Papirus icons for antiX Linux</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
papiris-antix
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
papiris-antix
</uninstall_package_names>
</app>
